<template>
  <div class="bbsl-common-page">
    <div class="bbsl-table-search">
      <el-form v-model="queryParam" label-width="auto">
        <el-row :gutter="10">
          <el-col :span="5">
            <el-form-item label="队伍名称">
              <el-input v-model="querys[1].value" clearable placeholder="请输入名称" />
            </el-form-item>
          </el-col>
          <el-col :span="4">
            <el-button icon="el-icon-search" type="primary" @click="handleSearch">搜索</el-button>
            <el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <div ref="contentPanel" class="bbsl-table-content">
      <div ref="btnPanel" class="bbsl-btn-content">
        <el-button icon="el-icon-plus" type="primary" @click="handleAdd">新增</el-button>
        <!--        <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">-->
        <!--          <el-button slot="reference" :disabled="!multipleSelection.length" icon="el-icon-delete"-->
        <!--                     style="margin-left: 10px"-->
        <!--                     type="danger">删除-->
        <!--          </el-button>-->
        <!--        </el-popconfirm>-->
        <el-button icon="el-icon-video-play" style="margin-left: 10px" type="success" @click="enable(1)">批量启用
        </el-button>
        <el-button icon="el-icon-circle-close" style="margin-left: 10px" type="warning" @click="enable(0)">批量禁用
        </el-button>
      </div>
      <el-table ref="multipleSelection" v-loading="loading" :cell-style="{ 'text-align': 'center' }" :data="tableData"
                :header-cell-style="{ 'text-align': 'center' }"
                :max-height="tableMaxHeight" :style="{ width: '100%' }" border
                size="mini" @row-dblclick="handleDbClick"
                @selection-change="handleSelectionChange">
        <el-table-column type="selection" width="55" />
        <el-table-column fixed label="序号" type="index" width="55" />
        <el-table-column fixed label="队伍名称" prop="name" show-overflow-tooltip width="150" />
        <el-table-column fixed label="队伍描述" prop="descripation" show-overflow-tooltip width="200" />
        <el-table-column fixed label="状态" prop="state" show-overflow-tooltip width="150">
          <template slot-scope="scope">
            <el-tag v-if="scope.row.state === 1" type="success">已启用</el-tag>
            <el-tag v-else-if="scope.row.state === 0" type="danger">已禁用</el-tag>
          </template>
        </el-table-column>
        <el-table-column fixed label="关联组" prop="orgNames" show-overflow-tooltip />

        <el-table-column :index="999" align="right" label="操作" width="200px">
          <template v-slot="{ row }">
            <el-button size="mini" type="warning" @click="handleUpdate(row)">
              修改
            </el-button>
            <el-button v-if="!row.memberId" size="mini" type="primary" @click="bindTeamMember(row)">
              关联组
            </el-button>

          </template>

        </el-table-column>
      </el-table>
      <el-pagination ref="paginationPanel" :current-page="queryParam.pageBean.page"
                     :page-size="queryParam.pageBean.pageSize" :page-sizes="[20, 30, 40, 50]"
                     :total="total" align="right"
                     background class="bbsl-pagination"
                     layout="total, sizes, prev, pager, next, jumper"
                     @size-change="handleSizeChange" @current-change="handleCurrentChange" />
    </div>
    <ServiceStrongDialog ref="formModal" />
    <AssociateGroupsDialog ref="formModol" @refreshData="refreshData" />
    <!--    <GisMapDrawer ref="gisMapDrawer" @confirm="mapConfirm" />-->
  </div>
</template>

<script>
import {TableMixin} from '@/mixins/tableMixin'

import ServiceStrong from '@/views/Manage/duty/api/ServiceStrong'
import ServiceStrongDialog from '@/views/Manage/duty/components/ServiceStrongDialog'
import req from '@/request'
import AssociateGroupsDialog from '@/views/Manage/duty/components/AssociateGroupsDialog.vue'

const portal = window.context.portal
export default {
  name: 'serviceStrong',
  components: {
    AssociateGroupsDialog,
    ServiceStrongDialog

  },
  mixins: [TableMixin],
  data() {
    return {
      mapVisible: false,
      url: {
        delete: '/cmgtDutyService/v1/'
      },
      urls: {
        post: '/cmgtDutyService/v1/update/state'
      },
      querys: [
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'code_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'name_',
          relation: 'AND',
          value: ''
        }
      ],
      StshowFormDias: false,
      fuelTypes: []
      // equipmentList: [] // 关联区域列表
    }
  },
  created() {
  },
  mounted() {
  },
  methods: {
    enable(type) {
      console.log(this.multipleSelection, '777777777777')
      const pram = new FormData()
      pram.append('state', type)
      const queryString = 'ids=' + this.multipleSelection.map(id => id).join('&ids=')
      req.post(portal + this.urls.post + '?' + queryString, pram).then(res => {
        this.$notify({
          type: 'success',
          message: `${type == 1 ? '启用' : '禁用'}成功`,
          duration: 2000
        })
        this.loadData()
      })
    },
    refreshData() {
      this.loadData()
    },
    bindTeamMember(row) {
      this.$refs.formModol.open(row)
    },

    // 重置
    clearQuerys() {
      // this.querys[0].value = ''
      this.querys[1].value = ''
    },
    // 获取list
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      // if (this.querys[0].value) {
      //   this.queryParam.querys.push(this.querys[0])
      // }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      ServiceStrong.loadCmgtDutyJob(this.queryParam, res => {
        console.log(res, 'res')
        this.total = res.total
        this.tableData = res.rows
        this.$set(this.tableData)
        this.loading = false
      })
    },
    // 修改
    handleUpdate(row) {
      this.$refs.formModal.Update(row)
    },

    closeStshowForm() {
      this.StshowFormDias = false
    }

  }
}
</script>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}
</style>
